rizla

command module
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 31, 2016 License: MIT Imports: 6 Imported by: 0

README

Rizla builds, runs and monitors your Go Applications with ease.

Travis Widget Release Widget Report Widget License Widget Chat Widget

Get Started

$ rizla main.go #single project monitoring
$ rizla C:/myprojects/project1/main.go C:/myprojects/project2/main.go #multi projects monitoring

Want to use it from your project's source code? easy

$ cat from_code_simple.go
package main

import (
	"gopkg.in/kataras/rizla.v0/rizla"
)

func main() {
  // Build, run & start monitoring the projects
  rizla.Run("C:/iris-project/main.go", "C:/otherproject/main.go")
}
$ cat from_code_pro.go
package main

import (
	"gopkg.in/kataras/rizla.v0/rizla"
	"path/filepath"
	"runtime"
	"time"
	"os"
)

func main() {


  // Create a new project by the main source file
  project := rizla.NewProject("C:/myproject/main.go")

  // The below are optional

  // Optional, set the messages/logs output destination of our app project,
  // let's set them to their defaults
  project.Out = rizla.NewPrinter(os.Stdout)
  project.Err = rizla.NewPrinter(os.Stderr)

  project.Name = "My super project"
  // Allow reload every 3 seconds or more no less
  project.AllowReloadAfter = time.Duration(3) * time.Second
  // Custom subdirectory matcher, for the watcher, return true to include this folder to the watcher
  // the default is:
  project.Watcher = func(absolutePath string) bool {
     	base := filepath.Base(abs)
		return !(base == ".git" || base == "node_modules" || base == "vendor")
  }
  // Custom file matcher on runtime (file change), return true to reload when a file with this file name changed
  // the default is:
  project.Matcher = func(filename string) bool {
		isWindows = runtime.GOOS == "windows"
		goExt     = ".go"
		return (filepath.Ext(fullname) == goExt) ||
		(!isWindows && strings.Contains(fullname, goExt))
  }
  // Add arguments, these will be used from the executable file
  project.Args = []string{"-myargument","the value","-otherargument","a value"}
  // Custom callback before reload, the default is:
  project.OnReload = func(string) {
		fromproject := ""
		if p.Name != "" {
			fromproject = "From project '" + project.Name + "': "
		}
		project.Out.Infof("\n%sA change has been detected, reloading now...", fromproject)
   }
   // Custom callback after reload, the default is:
   project.OnReloaded = func(string) {
 		project.Out.Successf("ready!\n")
   }

  // End of optional

  // Add the project to the rizla container
  rizla.Add(project)
  //  Build, run & start monitoring the project(s)
  rizla.Run()
}

That's all!

Installation

The only requirement is the Go Programming Language

$ go get -u gopkg.in/kataras/rizla.v0

FAQ

Ask questions and get real-time answer from the Chat.

Features

  • Super easy - is created for everyone.
  • You can use it either as command line tool either as part of your project's source code!
  • Multi-Monitoring - Supports monitoring of unlimited projects
  • No forever loops with filepath.Walk, rizla uses the Operating System's signals to fire a reload.

People

If you'd like to discuss this package, or ask questions about it, feel free to Chat.

The author of rizla is @kataras.

Versioning

Current: v0.0.6

HISTORY file is your best friend!

Read more about Semantic Versioning 2.0.0

Todo

  • Tests
  • Provide full examples.

Third-Party Licenses

Third-Party Licenses can be found here

License

This project is licensed under the MIT License.

License can be found here.

Documentation

Overview

Package main rizla builds, runs and monitors your Go Applications with ease.

rizla main.go
rizla C:/myprojects/project1/main.go C:/myprojects/project2/main.go C:/myprojects/project3/main.go

Directories

Path Synopsis
Package rizla contains the source code of the rizla project
Package rizla contains the source code of the rizla project

Jump to